@@ -58,10 +58,10 @@ def build_types_reference(
 
     if reference.mutation:
         for name, field in reference.mutation.fields.items():
-            # Wrap all mutation fields to set the unwrapped_field attr
-            unwrapped_field = unwrap_field_type(field.type)
+            # Wrap all mutation fields to set the unwrapped_type attr
+            unwrapped_type = unwrap_field_type(field.type)
             wrapper = definitions.GraphQLField(field)
-            wrapper.unwrapped_field = unwrapped_field
+            wrapper.unwrapped_type = unwrapped_type
             reference.mutation.fields[name] = wrapper
 
     implemented_by = defaultdict(list)
